@@ -1,11 +1,11 @@
 import json
 import logging
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any, Dict, List, Optional
 
-from datayoga_core import expression, utils
+from datayoga_core import expression
 from datayoga_core.block import Block as DyBlock
-from datayoga_core.block import Result
 from datayoga_core.context import Context
+from datayoga_core.result import BlockResult, Result, Status
 
 logger = logging.getLogger("dy")
 
@@ -23,7 +23,7 @@ class Block(DyBlock):
             raise ValueError("map expression must be in a json-like format enclosed in { }")
         self.expression = expression.compile(self.properties["language"], expression_prop)
 
-    async def run(self, data: List[Dict[str, Any]]) -> Tuple[List[Dict[str, Any]], List[Result]]:
+    async def run(self, data: List[Dict[str, Any]]) -> BlockResult:
         logger.debug(f"Running {self.get_block_name()}")
         mapped_rows = self.expression.search_bulk(data)
         # we always add the internal fields back, in case they were dropped in the map operation
@@ -35,4 +35,4 @@ class Block(DyBlock):
             if original_opcode is not None:
                 mapped_row[Block.OPCODE_FIELD] = original_opcode
 
-        return utils.all_success(mapped_rows)
+        return BlockResult(processed=[Result(Status.SUCCESS,payload=row) for row in mapped_rows])
